@@ -25,7 +25,7 @@ use strict;
 use warnings;
 no warnings;
 
-our $VERSION = '2.131';
+our $VERSION = '2.133';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
@@ -720,7 +720,7 @@ sub build_makefile {
 		return;
 		}
 
-	$self->run( "$self->{perl} $self->{'Makefile.PL'} 2>&1" );
+	$self->run( "$self->{perl} $self->{'Makefile.PL'} 2>&1 0<&-" );
 
 	$self->_print( "done\n" );
 	}
